   function shrunk = bamspd(x, n, r, pij, lamj)
   %
   % CALL shrunk = bamspd(x, n, nuj, pij, lamj)
   %   INPUT: x - vector of wavelet coefs to be shrunk
   %          n - sample size (may be different from length(x),
   %              since x xan be a singleton, block, or level
   %          r - smoothnes od sd, influencing scale of prior,
   %          pij - proportion of the spread prior, small for j fine levels
   %               (j large), usually 0.5,...
   %          lamj - proportion of the skewed model in the likelihood,
   %               should be large for fine levels, usually 0.95
   %    OUTPUT: shrunk - shrunk coefficients
   %  Marianna Pensky and Brani Vidakovic, 2003
   %
   rho =  2.^(-(r+1/2)*1)/sqrt(n); %rho = tauj, j=2
   eulergamma = 0.57721566490153286061;
   gammastar = exp(-eulergamma);
   del = 0.0005; %increment in numerical derivation in I1star
   beta = (1-pij)/pij; 
   I0star = rho/2 .* gammastar^(-rho) .* exp(- rho .* x) .* ...
       gammainc0( gammastar * exp(x), rho + 1) ...
       +  rho/2 * gammastar^rho .* exp(rho * x) .*   ...
       gammainc1(  gammastar * exp(x), 1-rho);
   J1star = gammastar .* rho/2 .* exp(- rho .* x).* ...
       (gammastar.^(-rho-del-1) .* gammainc0( gammastar .* exp(x), ...
                     rho + del + 1)- ...
      gammastar^(-rho-1) .* gammainc0( gammastar .* exp(x), ...
      rho + 1))./(del) - ...
      gammastar .* rho/2 .* exp(rho .* x) .* ...
      (gammastar.^(rho+del-1) .* gammainc1( gammastar .* exp(x), ...
                     -rho - del + 1)- ...
      gammastar.^(rho-1) .* gammainc1( gammastar .* exp(x), ...
      -rho + 1))./(del);
  
  I1star = x .* I0star - J1star;
    
  I0 = rho/4 * exp(pi^2 * rho^2/12 - rho * x) .* ...
       (1 + exp(2 *rho * x) - erf( pi*rho/sqrt(12) - sqrt(3)*x/pi) - ...
       exp(2 * rho * x) .*    erf( pi*rho/sqrt(12) + sqrt(3)*x/pi) ); 
  %
  I1 = rho/24 * exp(pi^2*rho^2/12 - rho*x) .* ...
      (   rho * pi^2 .* (exp(2 * rho * x) - 1) + 6 * x .* (exp(2 * rho * x) + 1)     + ...
                     abs(pi^2 * rho - 6*x) .* erf(abs(pi^2*rho - 6*x)/(sqrt(12)*pi)) - ...
     exp(2*rho*x) .* abs(pi^2 * rho + 6*x) .* erf(abs(pi^2*rho + 6*x)/(sqrt(12)*pi)) );
    sig = pi/sqrt(6);
    nor_dens = 1./(sig * sqrt(2 * pi))  .* exp(- x.^2 ./(2 .* sig.^2));
    mu_dens = gammastar .* exp( x - gammastar .* exp(x));
    zeta = (1-lamj).*nor_dens + lamj .* mu_dens;
    shrunk = ((1-lamj) * I1 + lamj * I1star)./((1-lamj) * I0 + lamj * I0star + beta * zeta);
   
   %-------------------------------------
 