function X = rand_arma(n, phi, theta, sigma2)
% --------------------------------------------------------------------------
%   rand_arma(n, phi, theta, sigma) 
%      generates n observations from the
%      ARMA model specified by vectors of coefficients phi, theta  according to
%      the notation in the book of Brockwell and Davis.
%   Example of use:
%      >> y = rand_arma(10000, [0.2],[-0.6], 3^2);    
%      generates 10000 observations from 
%      X_t - 0.2 * X_{t-1} = Z_t - 0.6 * Z_{t-1}, Z(t) \sim WN(0,3^2).
%      It "burns in" with the first 1000 observations to aleviate
%      initial setting: X = zeros(p,1).
%----------------------------------------------------------------------------
if nargin < 4, sigma2=1; end
burnin = 1000;
phi=phi(:); theta=theta(:);
p = length(phi);
q = length(theta);
Z = sqrt(sigma2) * randn(q+n+burnin,1);
X = zeros(p,1);
   if p==0 && q==0
       for i=1:(burnin + n)
       Xnew = Z(i);
          X = [X; Xnew];
       end
   elseif p==0 && q > 0
       for i=1:(burnin + n)
       Xnew =  Z(i+q) + Z(i:(i+q-1))'* theta(q:-1:1);
       X = [X; Xnew];
       end
   elseif q==0 && p > 0
       for i=1:(burnin + n)
       Xnew = X(i:(i+p-1))' * phi(p:-1:1) + Z(i+q);
       X = [X; Xnew];
       end
   else
       for i=1:(burnin + n)
       Xnew = X(i:(i+p-1))' * phi(p:-1:1) + ...
           Z(i+q) + Z(i:(i+q-1))'* theta(q:-1:1);
       X = [X; Xnew];
       end
   end
X = X((burnin + 1 + p):(burnin + n + p));
%--------------------- version 1.03  Brani 2/15/03